@@ -67,10 +67,10 @@ mod raw {
             if let Err(err) = crate::engine::BusEngine::start(topic, parent, handle, request) {
                 fault(handle.into(), err as u32);
             }
-        }
 
-        #[cfg(feature = "rt")]
-        crate::task::wake();
+            #[cfg(feature = "rt")]
+            crate::task::work_it();
+        }
     }
 
     // Invoked by the operating system when a call has finished
@@ -86,6 +86,8 @@ mod raw {
 
         #[cfg(feature = "rt")]
         crate::task::wake();
+        #[cfg(feature = "rt")]
+        crate::task::work_it();
     }
 
     // Invoked by the operating system when the call this program made has failed
@@ -95,6 +97,8 @@ mod raw {
 
         #[cfg(feature = "rt")]
         crate::task::wake();
+        #[cfg(feature = "rt")]
+        crate::task::work_it();
     }
 
     // Invoked by the operating system when a call has been terminated by the caller
@@ -105,6 +109,17 @@ mod raw {
 
         #[cfg(feature = "rt")]
         crate::task::wake();
+        #[cfg(feature = "rt")]
+        crate::task::work_it();
+    }
+
+    // Invoked by the operating system when a call has been terminated by the caller
+    #[no_mangle]
+    pub extern "C" fn wasm_bus_wake() {
+        #[cfg(feature = "rt")]
+        crate::task::wake();
+        #[cfg(feature = "rt")]
+        crate::task::work_it();
     }
 
     #[link(wasm_import_module = "wasm-bus")]
