@@ -1,10 +1,3 @@
-#[cfg(feature = "process")]
-pub use super::process::{Child, Command, ExitStatus, Output};
-#[cfg(feature = "reqwest")]
-pub use super::reqwest::{header, http, Body, Client, ClientBuilder, Form, Mime, RequestBuilder};
-#[cfg(feature = "ws")]
-pub use super::ws::{SocketBuilder, WebSocket};
-
 pub use crate::abi::call;
 pub use crate::abi::Call;
 
@@ -14,6 +7,9 @@ pub use crate::task::listen;
 pub use crate::task::respond_to;
 #[cfg(feature = "rt")]
 pub use crate::task::serve;
+#[cfg(feature = "macros")]
+pub use wasm_bus_macros::*;
 
 pub use crate::abi::CallError;
 pub use crate::abi::CallHandle;
+pub use crate::abi::WasmBusSession;
