@@ -1,19 +1,19 @@
-use cooked_waker::*;
+use cooked_waker::WakeRef;
 use std::sync::atomic::*;
 
 #[derive(Debug, Default)]
-pub struct CounterWaker {
+pub struct RuntimeWaker {
     count: AtomicUsize,
 }
 
-impl CounterWaker {
+impl RuntimeWaker {
     #[allow(dead_code)]
     pub fn get(&self) -> usize {
         self.count.load(Ordering::SeqCst)
     }
 }
 
-impl WakeRef for CounterWaker {
+impl WakeRef for RuntimeWaker {
     fn wake_by_ref(&self) {
         let _prev = self.count.fetch_add(1, Ordering::SeqCst);
     }
